==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebCore/accessibility/AccessibilityTableHeaderContainer.h <==
/*
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 3.  Neither the name of Apple Computer, Inc. ("Apple") nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef AccessibilityTableHeaderContainer_h
#define AccessibilityTableHeaderContainer_h

#include "AccessibilityMockObject.h"
#include "AccessibilityTable.h"
#include "IntRect.h"

namespace WebCore {

class AccessibilityTableHeaderContainer : public AccessibilityMockObject {
    
private:
    AccessibilityTableHeaderContainer();
public:
    static PassRefPtr<AccessibilityTableHeaderContainer> create();
    virtual ~AccessibilityTableHeaderContainer();
    
    virtual AccessibilityRole roleValue() const OVERRIDE { return TableHeaderContainerRole; }
    
    virtual void addChildren() OVERRIDE;
    
    virtual LayoutRect elementRect() const OVERRIDE;
    
private:
    LayoutRect m_headerRect;
    
    virtual bool computeAccessibilityIsIgnored() const OVERRIDE;
}; 
    
} // namespace WebCore 

#endif // AccessibilityTableHeaderContainer_h

==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/accessibility/AccessibilityTableHeaderContainer.h <==
/*
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 3.  Neither the name of Apple Inc. ("Apple") nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef AccessibilityTableHeaderContainer_h
#define AccessibilityTableHeaderContainer_h

#include "AccessibilityMockObject.h"
#include "AccessibilityTable.h"
#include "IntRect.h"

namespace WebCore {

class AccessibilityTableHeaderContainer : public AccessibilityMockObject {
    
private:
    AccessibilityTableHeaderContainer();
public:
    static PassRefPtr<AccessibilityTableHeaderContainer> create();
    virtual ~AccessibilityTableHeaderContainer();
    
    virtual AccessibilityRole roleValue() const override { return TableHeaderContainerRole; }
    
    virtual void addChildren() override;
    
    virtual LayoutRect elementRect() const override;
    
private:
    LayoutRect m_headerRect;
    
    virtual bool computeAccessibilityIsIgnored() const override;
}; 
    
} // namespace WebCore 

#endif // AccessibilityTableHeaderContainer_h
